.. include:: ./README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :hidden:

   api
   how_it_works
   contributing

.. toctree::
   :caption: Usage
   :hidden:

   ./usage/general.md
   ./usage/cli.md
   ./usage/logging.md
   ./usage/slurm.md

.. toctree::
   :caption: Examples
   :hidden:

   ./examples/transformers.md
   ./examples/deepspeed.md
   ./examples/lightning.md
   ./examples/accelerate.md

.. sidebar-links::
   :github:
   :pypi: torchrunx
